#[non_exhaustive]pub enum MrBundleError {
IoError(String, Error),
MissingResources(Vec<ResourceIdentifier>),
UnusedResources(Vec<ResourceIdentifier>),
MsgpackEncodeError(Error),
MsgpackDecodeError(String, Error),
YamlError(Error),
ParentlessPath(PathBuf),
DirectoryExists(PathBuf),
}Expand description
Any error which can occur in this crate
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IoError(String, Error)
An IO error
MissingResources(Vec<ResourceIdentifier>)
A manifest references resources that were not provided when attempting to create a bundle.
UnusedResources(Vec<ResourceIdentifier>)
Resources were provided when attempting to create a bundle that were not referenced in the manifest.
MsgpackEncodeError(Error)
A messagepack encoding error
MsgpackDecodeError(String, Error)
A messagepack decoding error
YamlError(Error)
Available on crate feature
fs only.A YAML error
ParentlessPath(PathBuf)
Available on crate feature
fs only.A path with no parent directory
DirectoryExists(PathBuf)
Available on crate feature
fs only.A target directory already exists