resource_id_for_path

Function resource_id_for_path 

pub fn resource_id_for_path(
    path: impl AsRef<Path>,
) -> Option<ResourceIdentifier>
Available on crate feature fs only.
A recommended conversion from a path to a resource identifier.

Calling this function with its own output will produce the same result.